@@ -29,30 +29,16 @@
 #include <glib-object.h>
 
 #include "goabackendenums.h"
+#include "goadavconfig.h"
 
 G_BEGIN_DECLS
 
-typedef struct
-{
-  char *webdav_uri;
-  char *caldav_uri;
-  char *carddav_uri;
-  GoaProviderFeatures features;
-
-  /* Identity amendments made during discovery */
-  char *identity;
-  char *username;
-} GoaDavConfiguration;
-
-void                 goa_dav_configuration_free                (GoaDavConfiguration *config);
-
 #define GOA_TYPE_DAV_CLIENT (goa_dav_client_get_type ())
 G_DECLARE_FINAL_TYPE (GoaDavClient, goa_dav_client, GOA, DAV_CLIENT, GObject)
 
 GoaDavClient        *goa_dav_client_new                        (void);
 void                 goa_dav_client_check                      (GoaDavClient         *self,
-                                                                const char           *uri,
-                                                                const char           *username,
+                                                                GoaDavConfig         *config,
                                                                 const char           *password,
                                                                 gboolean              accept_ssl_errors,
                                                                 GCancellable         *cancellable,
@@ -62,8 +48,7 @@ gboolean             goa_dav_client_check_finish               (GoaDavClient
                                                                 GAsyncResult         *res,
                                                                 GError              **error);
 gboolean             goa_dav_client_check_sync                 (GoaDavClient         *self,
-                                                                const char           *uri,
-                                                                const char           *username,
+                                                                GoaDavConfig         *config,
                                                                 const char           *password,
                                                                 gboolean              accept_ssl_errors,
                                                                 GCancellable         *cancellable,
@@ -76,7 +61,7 @@ void                 goa_dav_client_discover                   (GoaDavClient
                                                                 GCancellable         *cancellable,
                                                                 GAsyncReadyCallback   callback,
                                                                 gpointer              user_data);
-GoaDavConfiguration *goa_dav_client_discover_finish            (GoaDavClient         *self,
+GPtrArray           *goa_dav_client_discover_finish            (GoaDavClient         *self,
                                                                 GAsyncResult         *res,
                                                                 GError              **error);
 
